TestDecision

Enum TestDecision 

pub enum TestDecision {
    Accept,
    Reject(String),
}
The final policy-based verdict of a test, after applying the test mode. Determines whether the test should be considered passing or failing.

Variants



Accept

The test is accepted (passes)



Reject(String)

The test is rejected (fails)

Implementations

Source

impl TestDecision

pub fn enforce(self)

Actually asserts the test according to the decision. Panics if the test is rejected.