pub enum TestMode {
Correct,
Strict,
Print {
filter: Vec<DimFilter>,
fail_only: bool,
},
FailIfRun,
}Variants
Correct
Numerical errors cause the test to fail. Compilation errors are accepted (do not fail the test).
Strict
Both numerical and compilation errors cause the test to fail.
All tests can be printed according to the given filter.
fail_only = true: only tests with numerical errors are marked as failed and printed.
fail_only = false: all tests are marked as failed and printed.
FailIfRun
Fail only if the test successfully runs. Compilation failures are ignored.
Helpful to isolate relevant tests
Implementations
Sourceimpl TestMode
impl TestMode
pub fn decide(&self, outcome: TestOutcome) -> TestDecision