pub enum TestOutcome {
Validated(ValidationResult),
CompileError(String),
}Expand description
The overall outcome of a test, combining execution and validation. Either the kernel was validated or failed to compile.
Variants
Validated(ValidationResult)
The kernel was executed and validation was performed
CompileError(String)
The kernel could not compile
Implementations
Sourceimpl TestOutcome
impl TestOutcome