TestTensor

Struct TestTensor 

pub struct TestTensor {
    pub handle: TensorHandle<TestRuntime>,
    pub host: HostData,
    pub quantization: Option<QuantizationInfo>,
}
A test tensor which might be marked as quantized.

This structure couples the device handle, the host reference data, and optional quantization metadata. If quantization is Some, the handle on the device is expected to contain quantized data (unless it’s a dummy quantization for testing purposes).

Fields

handle: TensorHandle<TestRuntime>

The device handle.

host: HostData

The host data, usually stored in f32 for easy reference comparison.

quantization: Option<QuantizationInfo>

Optional quantization info.