pub enum TestDecision {
Accept,
Reject(String),
}Expand description
The final policy-based verdict of a test, after applying the test mode. Determines whether the test should be considered passing or failing.
Variants
Implementations
Sourceimpl TestDecision
impl TestDecision